/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Areski Flissi.
Contributor(s): 

====================================================================*/

package org.objectweb.ccm.filetransfer.cif;

import org.objectweb.ccm.filetransfer.*;


/**
 * This is the implementation of the OMG IDL3 filetransfer::Channel component type.
 *
 * This class inherits from the local CCM_Channel interface
 * generated by the OpenCCM's IDL3 to IDL2 mapping generator.
 *
 * This class also implements the filetransfer::Images event sink interface
 * to consume Images events.
 *
 * @author <a href="mailto:Areski.Flissi@lifl.fr">Areski Flissi</A>
 */

public class ChannelImpl
    extends org.objectweb.ccm.filetransfer.ChannelSessionComposition.ComponentImpl {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The name of the component. */
    private String name_;

    

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public ChannelImpl() {
        
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL Components::EnterpriseComponent
    //
    // ==================================================================

    /**
     * Complete the component configuration.
     *
     * @exception org.omg.Components.InvalidConfiguration
     *            Thrown if the configuration is invalid.     
     */
    public void configuration_complete()
        throws org.omg.Components.InvalidConfiguration {
        // Checks if the configuration is not completed.
        if (name_ == null)
            throw new org.omg.Components.InvalidConfiguration();
         
   }

    // ==================================================================
    //
    // Methods for the OMG IDL org.omg.Components.SessionComponent
    //
    // ==================================================================

    /**
     * Container callback to signal that the component is removed.
     *
     * @throw org.omg.Components.CCMException For any problems.
     */
    public void ccm_remove() throws org.omg.Components.CCMException {
        // Release the associated frame.

    }

    // ==================================================================
    //
    // Methods for OMG IDL filetransfer::CCM_Channel
    //
    // ==================================================================

    /**
     * The mutator method for the attribute name.
     *
     * @param n The name.
     */
    public void the_name(String n) {
        name_ = n;
        
        

    }

    /**
     * The accessor method for the attribute name.
     *
     * @return The name.
     */
    public String the_name() {
        return name_;
    }

    // ==================================================================
    //
    // Methods for the OMG IDL filetransfer::CCM_ImagesReceiver interface.
    //
    // ==================================================================

    /**
     * Implementation of the OMG IDL filetransfer::ImagesReceiver::push operation.
     *
     * @param event The received event.
     */
    public void push(Images event) {
        
        

        // Send the file received from the Prog component to TV components
        System.out.println(event.filename + " received from Prog component, sending to TV component");
        get_context().push_to_tvs(
            new ImagesImpl(event.datafile, event.filename));
            
        

    }

}
